// frontend/src/components/UserList.jsx

import React, { useEffect, useState } from "react";
import "./style.css";
import EmployeeManagementListItem from "types/interface/employee-list-item.interface";
import { usePagination } from "hooks";
import { getEmployeeManagementRequest } from "apis";

export default function UserList() {
  const [loading, setLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);

  // 페이지네이션 관련 상태
  const {
    currentPage,
    setCurrentPage,
    currentSection,
    setCurrentSection,
    viewList,
    viewPageList,
    totalSection,
    setTotalList,
  } = usePagination<EmployeeManagementListItem>(20); // 20개씩 게시물 보여짐

  // API 응답 처리 함수
  const getEmployeeManagementResponse = (
    responseBody: EmployeeManagementListItem[] | null
  ) => {
    console.log("API Response Body:", responseBody); // 디버깅용 로그
    if (!responseBody) {
      setError("No response from server.");
      setLoading(false);
      return;
    }

    setTotalList(responseBody); // 페이지네이션을 위한 데이터 설정
    setLoading(false); // 로딩 종료
  };

  useEffect(() => {
    getEmployeeManagementRequest()
      .then(getEmployeeManagementResponse)
      .catch((err) => {
        console.error("API request failed:", err);
        setError("API request failed.");
        setLoading(false);
      });
  }, []);

  if (loading) {
    return <p>Loading users...</p>;
  }

  if (error) {
    return <p>Error: {error}</p>;
  }

  return (
    <div className="container mt-4">
      <h2>사용자 목록</h2>
      <table className="table table-striped">
        <thead>
          <tr>
            <th>Email</th>
            <th>닉네임</th>
            <th>전화번호</th>
            <th>주소</th>
            <th>상세주소</th>
            <th>프로필 이미지</th>
          </tr>
        </thead>
        <tbody>
          {viewList.length > 0 ? (
            viewList.map((user: EmployeeManagementListItem) => (
              <tr key={user.email}>
                <td>{user.email}</td>
                <td>{user.nickname}</td>
                <td>{user.telNumber}</td>
                <td>{user.address}</td>
                <td>{user.addressDetail || "N/A"}</td>
                <td>
                  {user.profileImage ? (
                    <img
                      src={user.profileImage}
                      alt="Profile"
                      width="50"
                      height="50"
                    />
                  ) : (
                    "N/A"
                  )}
                </td>
              </tr>
            ))
          ) : (
            <tr>
              <td colSpan={6}>No users found.</td>
            </tr>
          )}
        </tbody>
      </table>
    </div>
  );
}
